@@ -2,17 +2,13 @@
 
 Author: `Keith Hughitt <keith.hughitt@nasa.gov>`
 """
-import numpy as np
-
-import matplotlib as mpl
 import matplotlib.pyplot as plt
 
 import astropy.units as u
 
 from sunpy.map import GenericMap
-from sunpy.visualization import axis_labels_from_ctype, peek_show
-
 from sunpy.util import expand_list
+from sunpy.visualization import axis_labels_from_ctype, peek_show, wcsaxes_compat
 
 __all__ = ['CompositeMap']
 
@@ -31,35 +27,6 @@ class CompositeMap:
     args : [`~sunpy.map.Map` | string]
         One or more map of filepaths
 
-    Methods
-    -------
-    add_map(map, zorder=None, alpha=1, levels=False)
-        Adds a map to the CompositeMap
-    remove_map(index)
-        Removes and returns the map with the given index.
-    list_maps()
-        Prints a list of the currently included maps.
-    get_alpha(index=None)
-        Returns the alpha-channel value for a layer in the composite image
-    get_levels(index=None)
-        Returns the list of contour levels for a map within the CompositeMap.
-    get_plot_settings(index=None)
-        Returns the plot settings for a map within the CompositeMap.
-    get_zorder(index=None)
-        Returns the layering preference (z-order) for a map within the composite.
-    set_alpha(index, alpha)
-        Sets the alpha-channel value for a layer in the CompositeMap.
-    set_levels(index, levels, percent=False)
-        Sets the contour levels for a layer in the CompositeMap.
-    set_plot_settings(index, plot_setiings)
-        Set the plot settings for a map with the CompositeMap.
-    set_zorder(index, zorder)
-        Set the layering preference (z-order) for a map within the CompositeMap.
-    plot(figure=None, overlays=None, draw_limb=False,
-    draw_grid=False, colorbar=True, basic_plot=False,title="SunPy Plot",
-    matplot_args)
-        Plots the composite map object using matplotlib
-
     Examples
     --------
     >>> import sunpy.map
@@ -71,13 +38,14 @@ class CompositeMap:
     >>> comp_map.peek()  # doctest: +SKIP
 
     """
+
     def __init__(self, *args, **kwargs):
         self._maps = expand_list(args)
 
         for m in self._maps:
             if not isinstance(m, GenericMap):
                 raise ValueError(
-                           'CompositeMap expects pre-constructed map objects.')
+                    'CompositeMap expects pre-constructed map objects.')
 
         # Default alpha and zorder values
         alphas = [1] * len(self._maps)
@@ -259,7 +227,7 @@ class CompositeMap:
         if percent is False:
             self._maps[index].levels = levels
         else:
-            self._maps[index].levels = [self._maps[index].max()*level/100.0 for level in levels]
+            self._maps[index].levels = u.Quantity(levels, u.percent)
 
     def set_plot_settings(self, index, plot_settings):
         """Sets the plot settings for a layer in the composite image.
@@ -333,7 +301,7 @@ class CompositeMap:
         return self._maps[index].draw_limb(axes=axes, **kwargs)
 
     @u.quantity_input
-    def draw_grid(self, index=None, axes=None, grid_spacing: u.deg=20*u.deg, **kwargs):
+    def draw_grid(self, index=None, axes=None, grid_spacing: u.deg = 20*u.deg, **kwargs):
         """Draws a grid over the surface of the Sun.
 
         Parameters
@@ -371,9 +339,14 @@ class CompositeMap:
         ax = self._maps[index].draw_grid(axes=axes, grid_spacing=grid_spacing, **kwargs)
         return ax
 
-    def plot(self, axes=None, annotate=True,  # pylint: disable=W0613
+    def plot(self, axes=None, annotate=True,
              title="SunPy Composite Plot", **matplot_args):
-        """Plots the composite map object using matplotlib
+        """Plots the composite map object by calling :meth:`~sunpy.map.GenericMap.plot`
+        or :meth:`~sunpy.map.GenericMap.draw_contours`.
+
+        By default, each map is plotted as an image.  If a given map has levels
+        defined (via :meth:`~sunpy.map.CompositeMap.set_levels`), that map will instead
+        be plotted as contours.
 
         Parameters
         ----------
@@ -390,18 +363,27 @@ class CompositeMap:
             Title of the composite map.
 
         **matplot_args : `dict`
-            Matplotlib Any additional imshow arguments that should be used
+            Any additional Matplotlib arguments that should be used
             when plotting.
 
         Returns
         -------
         ret : `list`
             List of axes image or quad contour sets that have been plotted.
+
+        Notes
+        -----
+        If a line-width Matplotlib argument (``linewidth``, ``linewidths``, or ``lw``)
+        is provided, it will apply only to those maps that are plotted as contours.
+
+        If a transformation is required to overlay the maps with the correct
+        alignment, the plot limits may need to be manually set because
+        Matplotlib autoscaling may not work as intended.
         """
 
-        # Get current axes
+        # If axes are not provided, create a WCSAxes based on the first map
         if not axes:
-            axes = plt.gca()
+            axes = wcsaxes_compat.gca_wcs(self._maps[0].wcs)
 
         if annotate:
             axes.set_xlabel(axis_labels_from_ctype(self._maps[0].coordinate_system[0],
@@ -415,35 +397,28 @@ class CompositeMap:
         # Plot layers of composite map
         for m in self._maps:
             # Parameters for plotting
-            bl = m._get_lon_lat(m.bottom_left_coord)
-            tr = m._get_lon_lat(m.top_right_coord)
-            x_range = list(u.Quantity([bl[0], tr[0]]).to(m.spatial_units[0]).value)
-            y_range = list(u.Quantity([bl[1], tr[1]]).to(m.spatial_units[1]).value)
             params = {
-                "origin": "lower",
-                "extent": x_range + y_range,
-                "cmap": m.plot_settings['cmap'],
-                "norm": m.plot_settings['norm'],
                 "alpha": m.alpha,
                 "zorder": m.zorder,
             }
             params.update(matplot_args)
 
             # The request to show a map layer rendered as a contour is indicated by a
-            # non False levels property.  If levels is False, then the layer is
-            # rendered using imshow.
+            # non False levels property.
             if m.levels is False:
-                # Check for the presence of masked map data
-                if m.mask is None:
-                    ret.append(axes.imshow(m.data, **params))
-                else:
-                    ret.append(axes.imshow(np.ma.array(np.asarray(m.data), mask=m.mask), **params))
+                # Check if any linewidth argument is provided, if so, then delete it from params.
+                for item in ['linewidth', 'linewidths', 'lw']:
+                    if item in matplot_args:
+                        del params[item]
+
+                # We tell GenericMap.plot() that we need to autoalign the map
+                if wcsaxes_compat.is_wcsaxes(axes):
+                    params['autoalign'] = True
+
+                params['annotate'] = False
+                ret.append(m.plot(**params))
             else:
-                # Check for the presence of masked map data
-                if m.mask is None:
-                    ret.append(axes.contour(m.data, m.levels, **params))
-                else:
-                    ret.append(axes.contour(np.ma.array(np.asarray(m.data), mask=m.mask), m.levels, **params))
+                ret.append(m.draw_contours(m.levels, **params))
 
                 # Set the label of the first line so a legend can be created
                 ret[-1].collections[0].set_label(m.name)
@@ -456,8 +431,7 @@ class CompositeMap:
         return ret
 
     @peek_show
-    def peek(self, colorbar=True, basic_plot=False, draw_limb=True,
-             draw_grid=False, **matplot_args):
+    def peek(self, colorbar=True, draw_limb=True, draw_grid=False, **matplot_args):
         """
         Displays a graphical overview of the data in this object for user evaluation.
         For the creation of plots, users should instead use the `~sunpy.map.CompositeMap.plot`
@@ -469,10 +443,6 @@ class CompositeMap:
             Whether to display a colorbar next to the plot.
             If specified as an integer a colorbar is plotted for that index.
 
-        basic_plot : `bool`
-            If true, the data is plotted by itself at it's natural scale; no
-            title, labels, or axes are shown.
-
         draw_limb : `bool`
             If true, draws a circle representing the solar limb.
 
@@ -485,16 +455,9 @@ class CompositeMap:
         """
 
         # Create a figure and add title and axes
-        figure = plt.figure(frameon=not basic_plot)
+        figure = plt.figure()
 
-        # Basic plot
-        if basic_plot:
-            axes = plt.Axes(figure, [0., 0., 1., 1.])
-            axes.set_axis_off()
-            figure.add_axes(axes)
-            matplot_args.update({'annotate': False})
-        else:
-            axes = figure.add_subplot(111)
+        axes = figure.add_subplot(111, projection=self._maps[0])
 
         ret = self.plot(axes=axes, **matplot_args)
 
@@ -521,4 +484,3 @@ class OutOfRangeAlphaValue(ValueError):
     """Exception to raise when an alpha value outside of the range 0-1 is
     requested.
     """
-    pass
