@@ -8,10 +8,12 @@ from astropy.coordinates import CartesianRepresentation, HeliocentricMeanEclipti
 from astropy.visualization import PowerStretch
 from astropy.visualization.mpl_normalize import ImageNormalize
 
+from sunpy import log
 from sunpy.map import GenericMap
 from sunpy.map.sources.source_type import source_stretch
+from sunpy.time import parse_time
 
-__all__ = ['EITMap', 'LASCOMap', 'MDIMap']
+__all__ = ['EITMap', 'LASCOMap', 'MDIMap', 'MDISynopticMap']
 
 
 class EITMap(GenericMap):
@@ -37,7 +39,8 @@ class EITMap(GenericMap):
         # Assume pixel units are arcesc if not given
         header['cunit1'] = header.get('cunit1', 'arcsec')
         header['cunit2'] = header.get('cunit2', 'arcsec')
-
+        if 'waveunit' not in header or not header['waveunit']:
+            header['waveunit'] = "Angstrom"
         super().__init__(data, header, **kwargs)
 
         self._nickname = self.detector
@@ -49,10 +52,6 @@ class EITMap(GenericMap):
     def detector(self):
         return "EIT"
 
-    @property
-    def waveunit(self):
-        return "Angstrom"
-
     @property
     def rsun_obs(self):
         """
@@ -112,7 +111,7 @@ class LASCOMap(GenericMap):
                                                                 self.meta.get('time_obs')
                                                                 )
                                              )
-            self.meta['date-obs'] = datestr
+            self.meta['date-obs'] = parse_time(datestr).isot
 
         # If non-standard Keyword is present, correct it too, for compatibility.
         if 'date_obs' in self.meta:
@@ -122,6 +121,17 @@ class LASCOMap(GenericMap):
         self.plot_settings['norm'] = ImageNormalize(
             stretch=source_stretch(self.meta, PowerStretch(0.5)), clip=False)
 
+        # For Helioviewer images, clear rotation metadata, as these have already been rotated.
+        # Also check that all CROTAn keywords exist to make sure that it's an untouched
+        # Helioviewer file.
+        if ('helioviewer' in self.meta
+                and 'crota' in self.meta and 'crota1' in self.meta and 'crota2' in self.meta):
+            log.debug("LASCOMap: Cleaning up CROTAn keywords "
+                      "because the map has already been rotated by Helioviewer")
+            self.meta.pop('crota')
+            self.meta.pop('crota1')
+            self.meta['crota2'] = 0
+
     @property
     def measurement(self):
         """
@@ -168,13 +178,18 @@ class MDIMap(GenericMap):
         super().__init__(data, header, **kwargs)
 
         # Fill in some missing or broken info
-        self._nickname = self.detector + " " + self.measurement
         vmin = np.nanmin(self.data)
         vmax = np.nanmax(self.data)
-        if abs(vmin) > abs(vmax):
-            self.plot_settings['norm'] = colors.Normalize(-vmin, vmin)
-        else:
-            self.plot_settings['norm'] = colors.Normalize(-vmax, vmax)
+        threshold = max([abs(vmin), abs(vmax)])
+        self.plot_settings['norm'] = colors.Normalize(-threshold, threshold)
+
+    @staticmethod
+    def _is_mdi_map(header):
+        return header.get('instrume') == 'MDI' or header.get('camera') == 'MDI'
+
+    @staticmethod
+    def _is_synoptic_map(header):
+        return 'Synoptic Chart' in header.get('CONTENT', '')
 
     @property
     def _supported_observer_coordinates(self):
@@ -186,7 +201,7 @@ class MDIMap(GenericMap):
                 ] + super()._supported_observer_coordinates
 
     @property
-    def detector(self):
+    def instrument(self):
         return "MDI"
 
     @property
@@ -196,11 +211,40 @@ class MDIMap(GenericMap):
     @property
     def measurement(self):
         """
-        Returns the type of data in the map.
+        Returns the measurement type.
         """
-        return "magnetogram" if self.meta.get('dpc_obsr', " ").find('Mag') != -1 else "continuum"
+        return self.meta.get('CONTENT', '')
 
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an MDI image"""
-        return header.get('instrume') == 'MDI' or header.get('camera') == 'MDI'
+        return cls._is_mdi_map(header) and not cls._is_synoptic_map(header)
+
+
+class MDISynopticMap(MDIMap):
+    """
+    SOHO MDI synoptic magnetogram Map.
+
+    See the docstring of `MDIMap` for information on the MDI instrument.
+    """
+    def __init__(self, data, header, **kwargs):
+        # FITS doesn't like "Degree" as a unit
+        if header['cunit1'] == 'Degree':
+            header['cunit1'] = 'deg'
+        # Sine Latitude is not a valid unit - see Thompson 2006, section 5.5
+        # for how to properly represent the cylindrical equal area (CEA) projection
+        if header['cunit2'] == 'Sine Latitude':
+            header['cdelt2'] = 180 / np.pi * header['cdelt2']
+            header['cunit2'] = 'deg'
+        if 'date-obs' not in header:
+            header['date-obs'] = header['t_obs']
+            header['date-obs'] = parse_time(header['date-obs']).isot
+        for i in [1, 2]:
+            if header.get(f'CRDER{i}') == 'nan':
+                header.pop(f'CRDER{i}')
+        super().__init__(data, header, **kwargs)
+
+    @classmethod
+    def is_datasource_for(cls, data, header, **kwargs):
+        """Determines if header corresponds to an MDI image"""
+        return cls._is_mdi_map(header) and cls._is_synoptic_map(header)
