@@ -7,7 +7,6 @@ from astropy.wcs import WCS
 
 import sunpy.map
 from sunpy.coordinates import frames, sun
-from sunpy.sun.constants import radius as rsun
 from sunpy.util.metadata import MetaDict
 
 
@@ -174,5 +173,6 @@ def test_carrington_self_observer():
     coord = SkyCoord(70*u.deg, -30*u.deg, 1*u.au, observer='self',
                      obstime='2013-10-28 00:00', frame=frames.HeliographicCarrington)
     header = sunpy.map.make_fitswcs_header(np.zeros((10, 10)), coord)
-    assert header['rsun_obs'] == sun._angular_radius(rsun, coord.radius).to_value(u.arcsec)
+    assert header['rsun_obs'] == sun._angular_radius(coord.rsun,
+                                                     coord.radius).to_value(u.arcsec)
     assert header['dsun_obs'] == coord.radius.to_value(u.m)
