@@ -60,6 +60,11 @@ class TestMap:
         sequence = sunpy.map.Map(a_list_of_many, sequence=True)
         assert isinstance(sequence, sunpy.map.MapSequence)
 
+    def test_mapsequence_sortby(self):
+        # Test making a MapSequence with sortby kwarg
+        sequence = sunpy.map.Map(a_list_of_many, sequence=True, sortby=None)
+        assert isinstance(sequence, sunpy.map.MapSequence)
+
     def test_composite(self):
         # Test making a CompositeMap
         comp = sunpy.map.Map(AIA_171_IMAGE, RHESSI_IMAGE, composite=True)
@@ -254,8 +259,8 @@ def test_map_list_urls_cache():
 @pytest.mark.parametrize('file, mapcls',
                          [[filepath / 'EIT' / "efz20040301.000010_s.fits", sunpy.map.sources.EITMap],
                           [filepath / "lasco_c2_25299383_s.fts", sunpy.map.sources.LASCOMap],
-                          [filepath / "mdi_fd_Ic_6h_01d.5871.0000_s.fits", sunpy.map.sources.MDIMap],
-                          [filepath / "mdi_fd_M_96m_01d.5874.0005_s.fits", sunpy.map.sources.MDIMap],
+                          [filepath / "mdi.fd_Ic.20101015_230100_TAI.data.fits", sunpy.map.sources.MDIMap],
+                          [filepath / "mdi.fd_M_96m_lev182.20101015_191200_TAI.data.fits", sunpy.map.sources.MDIMap],
                           [filepath / "euvi_20090615_000900_n4euA_s.fts", sunpy.map.sources.EUVIMap],
                           [filepath / "cor1_20090615_000500_s4c1A.fts", sunpy.map.sources.CORMap],
                           [filepath / "hi_20110910_114721_s7h2A.fts", sunpy.map.sources.HIMap],
