@@ -33,7 +33,7 @@ class HelioviewerClient:
     @lazyproperty
     def data_sources(self):
         """
-        We trawl through the return from `getDataSources` to create a clean
+        We trawl through the return from ``getDataSources`` to create a clean
         dictionary for all available sourceIDs.
 
         Here is a list of all of them: https://api.helioviewer.org/docs/v2/#appendix_datasources
@@ -78,11 +78,12 @@ class HelioviewerClient:
         Finds the closest image available for the specified source and date.
         **This does not download any file.**
 
-        This uses `getClosestImage <https://api.helioviewer.org/docs/v2/#OfficialClients>`_ from the Helioviewer API.
+        This uses `getClosestImage <https://api.helioviewer.org/docs/v2/#OfficialClients>`_
+        from the Helioviewer API.
 
         .. note::
-            We can use `observatory` and `measurement` or `instrument` and `measurement` to get the value for source ID which
-            can then be used to get required information.
+            We can use ``observatory`` and ``measurement`` or ``instrument`` and ``measurement`` to
+            get the value for source ID which can then be used to get required information.
 
         Parameters
         ----------
@@ -109,9 +110,9 @@ class HelioviewerClient:
         Examples
         --------
         >>> from sunpy.net import helioviewer
-        >>> client = helioviewer.HelioviewerClient()  # doctest: +REMOTE_DATA
-        >>> metadata = client.get_closest_image('2012/01/01', source_id=11)  # doctest: +REMOTE_DATA
-        >>> print(metadata['date'])  # doctest: +REMOTE_DATA
+        >>> client = helioviewer.HelioviewerClient()  # doctest: +SKIP
+        >>> metadata = client.get_closest_image('2012/01/01', source_id=11)  # doctest: +SKIP
+        >>> print(metadata['date'])  # doctest: +SKIP
         2012-01-01T00:00:07.000
         """
         if source_id is None:
@@ -134,13 +135,13 @@ class HelioviewerClient:
         """
         Downloads the JPEG 2000 that most closely matches the specified time and
         data source.
-        We can use `observatory` and `measurement` or `instrument` and `measurement` to get the value for source ID which
-        can then be used to get required information.
-        This uses `getJP2Image <https://api.helioviewer.org/docs/v2/#JPEG2000>`_ from the Helioviewer API.
+
+        This uses `getJP2Image <https://api.helioviewer.org/docs/v2/#JPEG2000>`_
+        from the Helioviewer API.
 
         .. note::
-            We can use `observatory` and `measurement` or `instrument` and `measurement` to get the value for source ID which
-            can then be used to get required information.
+            We can use ``observatory`` and ``measurement`` or ``instrument`` and ``measurement``
+            to get the value for source ID which can then be used to get required information.
 
         Parameters
         ----------
@@ -176,12 +177,12 @@ class HelioviewerClient:
         --------
         >>> import sunpy.map
         >>> from sunpy.net import helioviewer
-        >>> hv = helioviewer.HelioviewerClient()  # doctest: +REMOTE_DATA
+        >>> hv = helioviewer.HelioviewerClient()  # doctest: +SKIP
         >>> filepath = hv.download_jp2('2012/07/03 14:30:00', observatory='SDO',
-        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +REMOTE_DATA
-        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', observatory='SDO', measurement='continuum')  # doctest: +REMOTE_DATA
-        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', instrument='HMI', measurement='continuum')  # doctest: +REMOTE_DATA
-        >>> aia = sunpy.map.Map(filepath)  # doctest: +REMOTE_DATA
+        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +SKIP
+        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', observatory='SDO', measurement='continuum')  # doctest: +SKIP
+        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', instrument='HMI', measurement='continuum')  # doctest: +SKIP
+        >>> aia = sunpy.map.Map(filepath)  # doctest: +SKIP
         >>> aia.peek()  # doctest: +SKIP
         """
         if source_id is None:
@@ -199,13 +200,13 @@ class HelioviewerClient:
         """
         Get the XML header embedded in a JPEG2000 image. Includes the FITS header as well as a section
         of Helioviewer-specific metadata.
-        We can use `observatory` and `measurement` or `instrument` and `measurement` to get the value for source ID which
-        can then be used to get required information.
-        This uses `getJP2Header <https://api.helioviewer.org/docs/v2/#JPEG2000>`_ from the Helioviewer API.
+
+        This uses `getJP2Header <https://api.helioviewer.org/docs/v2/#JPEG2000>`_
+        from the Helioviewer API.
 
         .. note::
-            We can use `observatory` and `measurement` or `instrument` and `measurement` to get the value for source ID which
-            can then be used to get required information.
+            We can use ``observatory`` and ``measurement`` or ``instrument`` and ``measurement``
+            to get the value for source ID which can then be used to get required information.
 
         Parameters
         ----------
@@ -233,13 +234,13 @@ class HelioviewerClient:
         Examples
         --------
         >>> from sunpy.net import helioviewer
-        >>> hv = helioviewer.HelioviewerClient()  # doctest: +REMOTE_DATA
+        >>> hv = helioviewer.HelioviewerClient()  # doctest: +SKIP
         >>> header = hv.get_jp2_header('2012/07/03', observatory='SDO',
-        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +REMOTE_DATA
+        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +SKIP
         >>> # The key 'fits' can be used to get the fits header information
-        >>> fits_header = header['fits']  # doctest: +REMOTE_DATA
+        >>> fits_header = header['fits']  # doctest: +SKIP
         >>> # The keys 'helioviewer' can be used to extract the helioviewer specific metadata.
-        >>> helioviewer_meta_data = header['helioviewer']  # doctest: +REMOTE_DATA
+        >>> helioviewer_meta_data = header['helioviewer']  # doctest: +SKIP
         """
         if jp2_id is None:
             jp2_id = self.get_closest_image(
@@ -287,7 +288,7 @@ class HelioviewerClient:
         Parameters
         ----------
         date : `astropy.time.Time`, `str`
-            A `parse_time` parsable string or `~astropy.time.Time` object
+            A `~sunpy.time.parse_time` parsable string or `~astropy.time.Time` object
             for the desired date of the image
         image_scale : `float`
             The zoom scale of the image in arcseconds per pixel.
@@ -366,13 +367,13 @@ class HelioviewerClient:
         Examples
         --------
         >>> from sunpy.net.helioviewer import HelioviewerClient
-        >>> hv = HelioviewerClient()  # doctest: +REMOTE_DATA
+        >>> hv = HelioviewerClient()  # doctest: +SKIP
         >>> file = hv.download_png('2012/07/16 10:08:00', 2.4,
         ...                        "[SDO,AIA,AIA,171,1,100]",
-        ...                        x0=0, y0=0, width=1024, height=1024)   # doctest: +REMOTE_DATA
+        ...                        x0=0, y0=0, width=1024, height=1024)   # doctest: +SKIP
         >>> file = hv.download_png('2012/07/16 10:08:00', 4.8,
         ...                        "[SDO,AIA,AIA,171,1,100],[SOHO,LASCO,C2,white-light,1,100]",
-        ...                        x1=-2800, x2=2800, y1=-2800, y2=2800)   # doctest: +REMOTE_DATA
+        ...                        x1=-2800, x2=2800, y1=-2800, y2=2800)   # doctest: +SKIP
         """
         params = {
             "action": "takeScreenshot",
