@@ -3,7 +3,9 @@ This module provies a non-comprehensive collection of solar physical constants.
 """
 # TODO: Need better sources for some constants as well as error values.
 import astropy.constants.astropyconst20 as astrocon
+import astropy.units as u
 from astropy.constants import Constant
+from astropy.time import Time
 
 __all__ = ['physical_constants']
 
@@ -12,8 +14,10 @@ physical_constants = {}
 # references
 gsfc_fact = "https://nssdc.gsfc.nasa.gov/planetary/factsheet/sunfact.html"
 allen = "Allen's Astrophysical Quantities 4th Ed."
+archinal = 'Archinal et al. 2018'
 asplund = "Asplund et al. 2006"
 fivian = "Fivian et al. 2008"
+meeus = "Meeus 1998 Astronomical Algorithms 2nd Ed."
 
 physical_constants['mass'] = astrocon.M_sun
 physical_constants['radius'] = astrocon.R_sun
@@ -144,3 +148,43 @@ physical_constants['ellipticity'] = Constant('', "ellipticity",
 physical_constants['GM'] = Constant('mu', "standard gravitational parameter",
                                     132.712e6, 'km**3 s**-2', 0,
                                     gsfc_fact, system='si')
+
+# longitude of the prime meridian (without light travel time to Earth
+# and aberration effects) is 84.176 degrees eastward at J2000
+physical_constants['W_0'] = Constant('W_0',
+                                     'longitude of the prime meridian (epoch J2000.0)',
+                                     84.176, 'deg',
+                                     0, archinal,
+                                     system='si')
+
+# the definitional (fixed) rotation rate of the Sun relative to the stars (i.e., sidereal rotation rate)
+physical_constants['sidereal rotation rate'] = Constant('', 'sidereal rotation rate',
+                                                        14.1844, 'deg day**-1', 0,
+                                                        archinal, system='si')
+
+# time in Julian Days (TT) of the start of the first Carrington rotation
+first_carrington_rotation = Time(2398167.4, format='jd', scale='tt')
+physical_constants['first Carrington rotation (JD TT)'] = Constant('',
+                                                                   'first Carrington '
+                                                                   'rotation (JD TT)',
+                                                                   first_carrington_rotation.tt.jd,
+                                                                   'day', 0.1,
+                                                                   meeus, system='si')
+
+# length of the mean Carrington rotation as seen from Earth
+# the rotation rate of the Sun appears to be slower by the rate at which the Earth orbits the Sun
+period = 1 / (physical_constants['sidereal rotation rate'] / (360*u.deg) - 1 / u.yr)
+physical_constants['mean synodic period'] = Constant('',
+                                                     'mean synodic period',
+                                                     period.to_value('day'), 'day', 0,
+                                                     archinal, system='si')
+
+# Sun's north pole is oriented RA=286.13 deg, Dec=63.87 deg in ICRS and HCRS
+physical_constants['alpha_0'] \
+    = Constant('alpha_0',
+               'right ascension (RA) of the north pole (epoch J2000.0)',
+               286.13, 'deg', 0, archinal, system='si')
+physical_constants['delta_0'] \
+    = Constant('delta_0',
+               'declination of the north pole (epoch J2000.0)',
+               63.87, 'deg', 0, archinal, system='si')
