@@ -1,4 +1,3 @@
-import os
 import platform
 import warnings
 from pathlib import Path
@@ -11,6 +10,9 @@ import pkg_resources
 import pytest
 
 import astropy
+from astropy.wcs.wcs import FITSFixedWarning
+
+import sunpy.map
 
 __all__ = ['skip_windows', 'skip_glymur', 'skip_ana', 'skip_32bit',
            'warnings_as_errors', 'asdf_entry_points']
@@ -78,7 +80,7 @@ def figure_test(test_function):
     in the library. A PNG is also created in the 'result_image' directory,
     which is created on the current path.
 
-    All such decorated tests are marked with `pytest.mark.figure` for convenient filtering.
+    All such decorated tests are marked with `pytest.mark.mpl_image` for convenient filtering.
 
     Examples
     --------
@@ -99,49 +101,9 @@ def figure_test(test_function):
         if ret is None:
             ret = plt.gcf()
         return ret
-
     return test_wrapper
 
 
-# Skip coverage on this because we test it every time the CI runs --coverage!
-def _patch_coverage(testdir, sourcedir):  # pragma: no cover
-    """
-    This function is used by the ``setup.py test`` command to change the
-    filepath of the source code from the temporary directory "setup.py"
-    installs the code into to the actual directory "setup.py" was executed in.
-    """
-    import coverage
-
-    coveragerc = os.path.join(os.path.dirname(__file__), "coveragerc")
-
-    # Load the .coverage file output by pytest-cov
-    covfile = os.path.join(testdir, ".coverage")
-    cov = coverage.Coverage(covfile, config_file=coveragerc)
-    cov.load()
-    cov.get_data()
-
-    # Change the filename for the datafile to the new directory
-    if hasattr(cov, "_data_files"):
-        dfs = cov._data_files
-    else:
-        dfs = cov.data_files
-
-    dfs.filename = os.path.join(sourcedir, ".coverage")
-
-    # Replace the testdir with source dir
-    # Lovingly borrowed from astropy (see licences directory)
-    lines = cov.data._lines
-    for key in list(lines.keys()):
-        new_path = os.path.relpath(
-            os.path.realpath(key),
-            os.path.realpath(testdir))
-        new_path = os.path.abspath(
-            os.path.join(sourcedir, new_path))
-        lines[new_path] = lines.pop(key)
-
-    cov.save()
-
-
 def no_vso(f):
     """
     Disable the VSO client from returning results via Fido during this test.
@@ -157,3 +119,12 @@ def no_vso(f):
         return res
 
     return wrapper
+
+
+def fix_map_wcs(smap):
+    # Helper function to fix a WCS and silence the warnings
+    with warnings.catch_warnings():
+        warnings.filterwarnings('ignore', category=FITSFixedWarning)
+        wcs = smap.wcs
+        wcs.fix()
+    return sunpy.map.Map(smap.data, wcs)
