@@ -2,8 +2,11 @@
 This module provies GOES XRS `~sunpy.timeseries.TimeSeries` source.
 """
 import datetime
+from pathlib import Path
 from collections import OrderedDict
+from distutils.version import LooseVersion
 
+import h5netcdf
 import matplotlib.dates
 import matplotlib.ticker as mticker
 import numpy as np
@@ -14,7 +17,9 @@ import astropy.units as u
 from astropy.time import Time, TimeDelta
 
 import sunpy.io
-from sunpy.time import TimeRange, is_time_in_given_format, parse_time
+from sunpy import log
+from sunpy.io.file_tools import UnrecognizedFileTypeError
+from sunpy.time import is_time_in_given_format, parse_time
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
 from sunpy.util.metadata import MetaDict
 from sunpy.visualization import peek_show
@@ -53,6 +58,12 @@ class XRSTimeSeries(GenericTimeSeries):
     # Class attribute used to specify the source class of the TimeSeries.
     _source = 'xrs'
 
+    _netcdf_read_kw = {}
+    if h5netcdf.__version__ == LooseVersion("0.9"):
+        _netcdf_read_kw['decode_strings'] = True
+    if h5netcdf.__version__ >= LooseVersion("0.10"):
+        _netcdf_read_kw['decode_vlen_strings'] = True
+
     @peek_show
     def peek(self, title="GOES Xray Flux", **kwargs):
         """
@@ -71,28 +82,28 @@ class XRSTimeSeries(GenericTimeSeries):
         title : `str`. optional
             The title of the plot. Defaults to "GOES Xray Flux".
         **kwargs : `dict`
-            Additional plot keyword arguments that are handed to `axes.plot` functions
+            Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
+            functions.
         """
         # Check we have a timeseries valid for plotting
         self._validate_data_for_plotting()
 
-        figure = plt.figure()
-        axes = plt.gca()
+        fig, ax = plt.subplots()
 
         dates = matplotlib.dates.date2num(parse_time(self.to_dataframe().index).datetime)
 
-        axes.plot_date(dates, self.to_dataframe()['xrsa'], '-',
-                       label=r'0.5--4.0 $\AA$', color='blue', lw=2, **kwargs)
-        axes.plot_date(dates, self.to_dataframe()['xrsb'], '-',
-                       label=r'1.0--8.0 $\AA$', color='red', lw=2, **kwargs)
+        ax.plot_date(dates, self.to_dataframe()['xrsa'], '-',
+                     label=r'0.5--4.0 $\AA$', color='blue', lw=2, **kwargs)
+        ax.plot_date(dates, self.to_dataframe()['xrsb'], '-',
+                     label=r'1.0--8.0 $\AA$', color='red', lw=2, **kwargs)
 
-        axes.set_yscale("log")
-        axes.set_ylim(1e-9, 1e-2)
-        axes.set_title(title)
-        axes.set_ylabel('Watts m$^{-2}$')
-        axes.set_xlabel(datetime.datetime.isoformat(self.to_dataframe().index[0])[0:10])
+        ax.set_yscale("log")
+        ax.set_ylim(1e-9, 1e-2)
+        ax.set_title(title)
+        ax.set_ylabel('Watts m$^{-2}$')
+        ax.set_xlabel(datetime.datetime.isoformat(self.to_dataframe().index[0])[0:10])
 
-        ax2 = axes.twinx()
+        ax2 = ax.twinx()
         ax2.set_yscale("log")
         ax2.set_ylim(1e-9, 1e-2)
         labels = ['A', 'B', 'C', 'M', 'X']
@@ -101,57 +112,18 @@ class XRSTimeSeries(GenericTimeSeries):
         ax2.set_yticklabels(labels, minor=True)
         ax2.set_yticklabels([])
 
-        axes.yaxis.grid(True, 'major')
-        axes.xaxis.grid(False, 'major')
-        axes.legend()
+        ax.yaxis.grid(True, 'major')
+        ax.xaxis.grid(False, 'major')
+        ax.legend()
 
         # TODO: display better tick labels for date range (e.g. 06/01 - 06/05)
         formatter = matplotlib.dates.DateFormatter('%H:%M')
-        axes.xaxis.set_major_formatter(formatter)
+        ax.xaxis.set_major_formatter(formatter)
 
-        axes.fmt_xdata = matplotlib.dates.DateFormatter('%H:%M')
-        figure.autofmt_xdate()
+        ax.fmt_xdata = matplotlib.dates.DateFormatter('%H:%M')
+        fig.autofmt_xdate()
 
-        return figure
-
-    # TODO: is this part of the DL pipeline? If so delete.
-    @staticmethod
-    def _get_goes_sat_num(start, end):
-        """
-        Parses the query time to determine which GOES satellite to use.
-
-        Parameters
-        ----------
-        filepath : `str`
-            The path to the file you want to parse.
-        """
-        goes_operational = {
-            2: TimeRange('1980-01-04', '1983-05-01'),
-            5: TimeRange('1983-05-02', '1984-08-01'),
-            6: TimeRange('1983-06-01', '1994-08-19'),
-            7: TimeRange('1994-01-01', '1996-08-14'),
-            8: TimeRange('1996-03-21', '2003-06-19'),
-            9: TimeRange('1997-01-01', '1998-09-09'),
-            10: TimeRange('1998-07-10', '2009-12-02'),
-            11: TimeRange('2006-06-20', '2008-02-16'),
-            12: TimeRange('2002-12-13', '2007-05-09'),
-            13: TimeRange('2006-08-01', '2006-08-01'),
-            14: TimeRange('2009-12-02', '2010-11-05'),
-            15: TimeRange('2010-09-01', Time.now()),
-        }
-
-        sat_list = []
-        for sat_num in goes_operational:
-            if (goes_operational[sat_num].start <= start <= goes_operational[sat_num].end and
-                    goes_operational[sat_num].start <= end <= goes_operational[sat_num].end):
-                # if true then the satellite with sat_num is available
-                sat_list.append(sat_num)
-
-        if not sat_list:
-            # if no satellites were found then raise an exception
-            raise Exception('No operational GOES satellites within time range')
-        else:
-            return sat_list
+        return fig
 
     @classmethod
     def _parse_file(cls, filepath):
@@ -163,8 +135,14 @@ class XRSTimeSeries(GenericTimeSeries):
         filepath : `str`
             The path to the file you want to parse.
         """
-        hdus = sunpy.io.read_file(filepath)
-        return cls._parse_hdus(hdus)
+        if sunpy.io.detect_filetype(filepath) == "hdf5":
+            return cls._parse_netcdf(filepath)
+        try:
+            hdus = sunpy.io.read_file(filepath)
+        except UnrecognizedFileTypeError:
+            raise ValueError(f"{Path(filepath).name} is not supported. Only fits and netCDF (nc) can be read.")
+        else:
+            return cls._parse_hdus(hdus)
 
     @classmethod
     def _parse_hdus(cls, hdulist):
@@ -176,6 +154,7 @@ class XRSTimeSeries(GenericTimeSeries):
         hdulist : `astropy.io.fits.HDUList`
             A HDU list.
         """
+
         header = MetaDict(OrderedDict(hdulist[0].header))
         if len(hdulist) == 4:
             if is_time_in_given_format(hdulist[0].header['DATE-OBS'], '%d/%m/%Y'):
@@ -215,14 +194,56 @@ class XRSTimeSeries(GenericTimeSeries):
                              ('xrsb', u.W/u.m**2)])
         return data, header, units
 
+    @staticmethod
+    def _parse_netcdf(filepath):
+        """
+        Parses the netCDF GOES files to return the data, header and associated units.
+
+        Parameters
+        ----------
+        filepath : `~str`
+            The path of the file to parse
+        """
+        with h5netcdf.File(filepath, mode="r", **XRSTimeSeries._netcdf_read_kw) as d:
+
+            header = MetaDict(OrderedDict(d.attrs))
+            if "a_flux" in d.variables:
+                xrsa = np.array(d["a_flux"])
+                xrsb = np.array(d["b_flux"])
+                start_time_str = d["time"].attrs["units"].astype(str).lstrip("seconds since").rstrip("UTC")
+                times = parse_time(start_time_str) + TimeDelta(d["time"], format="sec")
+            elif "xrsa_flux" in d.variables:
+                xrsa = np.array(d["xrsa_flux"])
+                xrsb = np.array(d["xrsb_flux"])
+                start_time_str = d["time"].attrs["units"].astype(str).lstrip("seconds since")
+                times = parse_time(start_time_str) + TimeDelta(d["time"], format="sec")
+
+            else:
+                raise ValueError(f"The file {filepath} doesn't seem to be a GOES netcdf file.")
+
+        data = DataFrame({"xrsa": xrsa, "xrsb": xrsb}, index=times.datetime)
+        data = data.replace(-9999, np.nan)
+        units = OrderedDict([("xrsa", u.W/u.m**2),
+                             ("xrsb", u.W/u.m**2)])
+
+        return data, header, units
+
     @classmethod
     def is_datasource_for(cls, **kwargs):
         """
         Determines if header corresponds to a GOES lightcurve
         `~sunpy.timeseries.TimeSeries`.
         """
-        if 'source' in kwargs.keys():
-            if kwargs.get('source', ''):
-                return kwargs.get('source', '').lower().startswith(cls._source)
-        if 'meta' in kwargs.keys():
-            return kwargs['meta'].get('TELESCOP', '').startswith('GOES')
+        if "source" in kwargs.keys():
+            return kwargs["source"].lower().startswith(cls._source)
+        if "meta" in kwargs.keys():
+            return kwargs["meta"].get("TELESCOP", "").startswith("GOES")
+
+        if "filepath" in kwargs.keys():
+            try:
+                if sunpy.io.detect_filetype(kwargs["filepath"]) == "hdf5":
+                    with h5netcdf.File(kwargs["filepath"], mode="r", **cls._netcdf_read_kw) as f:
+                        return "XRS" in f.attrs["summary"].astype("str")
+            except Exception as e:
+                log.debug(f'Reading {kwargs["filepath"]} failed with the following exception:\n{e}')
+                return False
