@@ -3,6 +3,7 @@ from functools import partial
 import matplotlib.animation as mplanim
 import matplotlib.axes as maxes
 import matplotlib.backend_bases as mback
+import matplotlib.figure as mfigure
 import matplotlib.pyplot as plt
 import numpy as np
 import pytest
@@ -28,13 +29,10 @@ def button_func1(*args, **kwargs):
     print(*args, **kwargs)
 
 
-@pytest.mark.parametrize('fig, colorbar, buttons', ((None, False, [[], []]),
-                                                    (plt.figure, True, [[button_func1], ["hi"]])))
+@pytest.mark.parametrize('fig, colorbar, buttons',
+                         ((None, False, [[], []]),
+                          (mfigure.Figure(), True, [[button_func1], ["hi"]])))
 def test_base_func_init(fig, colorbar, buttons):
-    # We need to create figures within the test function rather than in parametrize()
-    if callable(fig):
-        fig = fig()
-
     data = np.random.random((3, 10, 10))
     func0 = partial(update_plotval, data=data)
     func1 = partial(update_plotval, data=data*10)
@@ -51,7 +49,7 @@ def test_base_func_init(fig, colorbar, buttons):
     tfa._set_active_slider(1)
     assert tfa.active_slider == 1
 
-    fig = plt.figure()
+    fig = tfa.fig
     event = mback.KeyEvent(name='key_press_event', canvas=fig.canvas, key='down')
     tfa._key_press(event)
     assert tfa.active_slider == 0
@@ -99,19 +97,17 @@ def test_base_func_init(fig, colorbar, buttons):
     tfa._mouse_click(event)
     assert tfa.active_slider == 0
 
-    # Close the figure if it is a pyplot figure
-    if fig in [plt.figure(i) for i in plt.get_fignums()]:
-        plt.close(fig)
 
-
-@pytest.fixture
-def funcanimator():
+# Make sure figures created directly and through pyplot work
+@pytest.fixture(params=[plt.figure, mfigure.Figure])
+def funcanimator(request):
     data = np.random.random((3, 10, 10))
     func = partial(update_plotval, data=data)
     funcs = [func]
     ranges = [(0, 3)]
+    fig = request.param()
 
-    return FuncAnimatorTest(data, funcs, ranges)
+    return FuncAnimatorTest(data, funcs, ranges, fig=fig)
 
 
 def test_to_anim(funcanimator):
@@ -123,6 +119,23 @@ def test_to_axes(funcanimator):
     assert isinstance(funcanimator.axes, maxes.SubplotBase)
 
 
+def test_axes_set():
+    data = np.random.random((3, 10, 10))
+    funcs = [partial(update_plotval, data=data)]
+    ranges = [(0, 3)]
+
+    # Create Figure for animator
+    fig1 = plt.figure()
+    # Create new Figure, Axes, and set current axes
+    fig2, ax = plt.subplots()
+    plt.sca(ax)
+    ani = FuncAnimatorTest(data, funcs, ranges, fig=fig1)
+    # Make sure the animator axes is now the current axes
+    assert plt.gca() is ani.axes
+
+    [plt.close(f) for f in [fig1, fig2]]
+
+
 def test_edges_to_centers_nd():
     edges_axis = 0
     axis_range = np.zeros((10, 2))
