@@ -3,6 +3,7 @@ from functools import partial
 import numpy as np
 
 import astropy.units as u
+from astropy.visualization import AsymmetricPercentileInterval
 from astropy.wcs.wcsapi import BaseLowLevelWCS
 
 from sunpy.extern import modest_image
@@ -59,10 +60,12 @@ class ArrayAnimatorWCS(ArrayAnimator):
     ylabel: `string`, optional
        The yaxis label to use when drawing a line plot. Setting the label on
        the y-axis on an image plot should be done via ``coord_params``.
-
+    clip_interval : two-element `~astropy.units.Quantity`, optional
+        If provided, the data for each step will be clipped to the percentile interval bounded by the two numbers.
     """
 
-    def __init__(self, data, wcs, slices, coord_params=None, ylim='dynamic', ylabel=None, **kwargs):
+    def __init__(self, data, wcs, slices, coord_params=None, ylim='dynamic', ylabel=None,
+                 clip_interval: u.percent = None, **kwargs):
         if not isinstance(wcs, BaseLowLevelWCS):
             raise ValueError("A WCS object should be provided that implements the astropy WCS API.")
         if wcs.pixel_n_dim != data.ndim:
@@ -88,6 +91,11 @@ class ArrayAnimatorWCS(ArrayAnimator):
         self.ylim = ylim
         self.ylabel = ylabel
 
+        if clip_interval is not None and len(clip_interval) != 2:
+            raise ValueError('A range of 2 values must be specified for clip_interval.')
+
+        self.clip_interval = clip_interval
+
         extra_slider_labels = []
         if "slider_functions" in kwargs and "slider_labels" not in kwargs:
             extra_slider_labels = [a.__name__ for a in kwargs['slider_functions']]
@@ -213,6 +221,8 @@ class ArrayAnimatorWCS(ArrayAnimator):
         the matplotlib artist.
         """
         ind = int(val)
+        if ind == int(slider.cval):
+            return
         ax_ind = self.slider_axes[slider.slider_ind]
         self.frame_slice[ax_ind] = ind
         self.slices_wcsaxes[self.wcs.pixel_n_dim - ax_ind - 1] = ind
@@ -262,15 +272,14 @@ class ArrayAnimatorWCS(ArrayAnimator):
         """
         Update the line plot.
         """
-        if val != slider.cval:
-            self.axes.reset_wcs(wcs=self.wcs, slices=self.slices_wcsaxes)
-            line.set_ydata(self.data[self.frame_index])
+        self.axes.reset_wcs(wcs=self.wcs, slices=self.slices_wcsaxes)
+        line.set_ydata(self.data[self.frame_index])
 
-            # If we are not setting ylim globally then we set it per frame.
-            if self.ylim == 'dynamic':
-                self.axes.set_ylim(self.data[self.frame_index].min(),
-                                   self.data[self.frame_index].max())
-            slider.cval = val
+        # If we are not setting ylim globally then we set it per frame.
+        if self.ylim == 'dynamic':
+            self.axes.set_ylim(self.data[self.frame_index].min(),
+                               self.data[self.frame_index].max())
+        slider.cval = val
 
     def plot_start_image_2d(self, ax):
         """
@@ -280,6 +289,9 @@ class ArrayAnimatorWCS(ArrayAnimator):
                        'origin': 'lower'}
         imshow_args.update(self.imshow_kwargs)
 
+        if self.clip_interval is not None:
+            imshow_args['vmin'], imshow_args['vmax'] = self._get_2d_plot_limits()
+
         im = modest_image.imshow(ax, self.data_transposed, **imshow_args)
 
         if 'extent' in imshow_args:
@@ -298,11 +310,23 @@ class ArrayAnimatorWCS(ArrayAnimator):
 
         return im
 
+    def _get_2d_plot_limits(self):
+        """
+        Get vmin, vmax of a data slice when clip_interval is specified.
+        """
+        percent_limits = self.clip_interval.to('%').value
+        vmin, vmax = AsymmetricPercentileInterval(*percent_limits).get_limits(self.data_transposed)
+        return vmin, vmax
+
     def update_plot_2d(self, val, im, slider):
         """
         Update the image plot.
         """
-        if val != slider.cval:
-            self.axes.reset_wcs(wcs=self.wcs, slices=self.slices_wcsaxes)
-            im.set_array(self.data_transposed)
-            slider.cval = val
+        self.axes.reset_wcs(wcs=self.wcs, slices=self.slices_wcsaxes)
+        im.set_array(self.data_transposed)
+
+        if self.clip_interval is not None:
+            vmin, vmax = self._get_2d_plot_limits()
+            im.set_clim(vmin, vmax)
+
+        slider.cval = val
